@@ -51,7 +51,7 @@ app_path="./"
 passed_time=0
 last_beep=0
 #graphBlocks=0
-OfflineMode="True"
+OfflineMode="False"
 #OldOfflineMode="False" #restore original state after recording
 
 #arrays, indexes, lenghts
