@@ -54,7 +54,7 @@ def main():
         data.debug=0
 
     #if not on the N900, a acceleration sensor has to be simulated
-    if os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord"): data.demo=0	#runs on real N900 hardware
+    if(os.path.exists("/sys/class/i2c-adapter/i2c-3/3-001d/coord")): data.demo=0	#runs on real N900 hardware
     else: data.demo=1	#runs on other hardware/OS
 
 
@@ -591,19 +591,19 @@ class frmViewWindow(QMainWindow):
 #        self.ui.lblTrigger.setText(str(data.trigger))
 #        self.ui.lblYscale.setText(str(data.Yscale))
         
-#        try:
-        start=str(data.StartDate)+" "+str(data.arrData[0][0])
-        stop=str(data.arrData[0][data.arrDataIndex-1])
-        t0=time.strptime(start, "%d-%m-%Y %H:%M:%S")
-        t1=time.strptime("01-01-2000 "+stop, "%d-%m-%Y %H:%M:%S")
-        tt0=time.mktime(t0)
-        tt1=time.mktime(t1)
-        dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
-        day=strftime("%A", time.gmtime(tt0))
-            
-            
+        try:
+            start=str(data.StartDate)+" "+str(data.arrData[0][0])
+            stop=str(data.arrData[0][data.arrDataIndex-1])
+            t0=time.strptime(start, "%d-%m-%Y %H:%M:%S")
+            t1=time.strptime("01-01-2000 "+stop, "%d-%m-%Y %H:%M:%S")
+            tt0=time.mktime(t0)
+            tt1=time.mktime(t1)
+            dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
+            day=strftime("%A", time.gmtime(tt0))
+        except:
+            dt=""
+            day=""            
         self.ui.lblTimes.setText("Start: "+str(day)+" "+str(data.arrData[0][0])+"   End: "+str(data.arrData[0][data.arrDataIndex-1])+"   Duration: "+str(dt))
-       
         self.ui.lblNote.setText(str(data.Note))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -630,6 +630,10 @@ class frmViewWindow(QMainWindow):
         r=OpenLogFile()    
         if(r==1): #file too long            
             QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
+        elif(r==2): #file does not exist
+#            closeEvent(0)
+            self.Open()
+            return
         LoadFileList()
         ProcessData()
         data.Xscale=1 #default zoom level
