@@ -105,9 +105,16 @@ def LoadFileList():
 #  Load log file  to read and visualise it
 ###########################################################################
 def OpenLogFile():    
-    Show_passed_time("OpenLogFile Start")
+#    Show_passed_time("OpenLogFile Start")
     print "Open Log file:",  data.logfolder+data.logfilename
-    file = open(data.logfolder+data.logfilename, 'r')
+    
+    if(not os.path.exists(data.logfolder)): #create log folder (dirty workaround for if folder is not existing
+        os.mkdir(data.logfolder)
+        data.lastlogfile=""
+
+    f=data.logfolder+data.logfilename
+    if(not os.path.exists(f) or data.logfilename==""): return 2 #selected file or folder does not exist 
+    file = open(f, 'r')
     data.arrDataIndex=0
     ret=0
     try:
@@ -153,7 +160,7 @@ def OpenLogFile():
         file.close()
     
     print "Loaded",  str(data.arrDataIndex),  "lines"
-    Show_passed_time("OpenLogFile End")
+#    Show_passed_time("OpenLogFile End")
     return ret
     
     
